Index: kernel/generic/src/main/kinit.c
===================================================================
--- kernel/generic/src/main/kinit.c	(revision 2f5769097aeb16476c39a32de0fe53503cf28a83)
+++ kernel/generic/src/main/kinit.c	(revision ff685c93ca4666ba47a3b747bd9da4268cc5aa47)
@@ -81,6 +81,6 @@
 #endif
 
-#define BOOT_PREFIX      "boot:"
-#define BOOT_PREFIX_LEN  5
+#define INIT_PREFIX      "init:"
+#define INIT_PREFIX_LEN  5
 
 /** Kernel initialization thread.
@@ -179,5 +179,5 @@
 		
 		/*
 		 * Construct task name from the 'boot:' prefix and the
 		 * name stored in the init structure (if any).
 		 */
@@ -190,8 +190,8 @@
 			name = "<unknown>";
 		
-		ASSERT(TASK_NAME_BUFLEN >= BOOT_PREFIX_LEN);
-		strncpy(namebuf, BOOT_PREFIX, TASK_NAME_BUFLEN);
-		strncpy(namebuf + BOOT_PREFIX_LEN, name,
-		    TASK_NAME_BUFLEN - BOOT_PREFIX_LEN);
+		ASSERT(TASK_NAME_BUFLEN >= INIT_PREFIX_LEN);
+		strncpy(namebuf, INIT_PREFIX, TASK_NAME_BUFLEN);
+		strncpy(namebuf + INIT_PREFIX_LEN, name,
+		    TASK_NAME_BUFLEN - INIT_PREFIX_LEN);
 		
 		int rc = program_create_from_image((void *) init.tasks[i].addr,
@@ -179,5 +179,5 @@
 		
 		/*
-		 * Construct task name from the 'boot:' prefix and the
+		 * Construct task name from the 'init:' prefix and the
 		 * name stored in the init structure (if any).
 		 */
